@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: barline.cpp 2981 2010-04-18 14:40:17Z lasconic $
+//  $Id: barline.cpp 3274 2010-07-12 08:58:45Z wschweer $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -69,7 +69,11 @@ void BarLine::getY(double* y1, double* y2) const
             StaffLines* l1   = measure->staffLines(staffIdx1);
             StaffLines* l2   = measure->staffLines(staffIdx2);
 
-            double yp = system->staff(staffIdx())->y();
+            double yp;
+            if (system)
+                  yp = system->staff(staffIdx())->y();
+            else
+                  yp = 0.0;
 
             *y1 = l1->y1() - yp;
             *y2 = l2->y2() - yp;
