@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: chord.cpp 3076 2010-05-14 10:22:21Z wschweer $
+//  $Id: chord.cpp 3461 2010-09-14 10:34:35Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -309,6 +309,11 @@ Chord::~Chord()
       delete _glissando;
       delete _stemSlash;
       delete _stem;
+      delete _hook;
+      foreach(LedgerLine* h, _ledgerLines)
+            delete h;
+      foreach(Note* n, _notes)
+            delete n;
       }
 
 //---------------------------------------------------------
@@ -394,7 +399,9 @@ void Chord::add(Element* e)
             Tremolo* tr = static_cast<Tremolo*>(e);
             if (tr->twoNotes()) {
                   Duration d = duration();
+                  int dots = d.dots();
                   d  = d.shift(-1);
+                  d.setDots(dots);
                   if (tr->chord1())
                         tr->chord1()->setDuration(d);
                   if (tr->chord2())
@@ -439,7 +446,9 @@ void Chord::remove(Element* e)
             Tremolo* tremolo = static_cast<Tremolo*>(e);
             if (tremolo->twoNotes()) {
                   Duration d = duration();
+                  int dots = d.dots();
                   d          = d.shift(1);
+                  d.setDots(dots);
                   if (tremolo->chord1())
                         tremolo->chord1()->setDuration(d);
                   if (tremolo->chord2())
