@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: edit.cpp 3117 2010-06-02 09:21:44Z wschweer $
+//  $Id: edit.cpp 3482 2010-09-21 07:10:03Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -558,7 +558,7 @@ void Score::putNote(const QPointF& pos, bool replace)
       Staff* st               = staff(staffIdx);
       KeySigEvent key         = st->keymap()->key(tick);
       int clef                = st->clef(tick);
-      int pitch               = line2pitch(line, clef, key.accidentalType);
+      int pitch               = line2pitch(line, clef, key.accidentalType());
       Part* instr             = st->part();
       _is.track               = staffIdx * VOICES + (_is.track % VOICES);
       _is.pitch               = pitch;
@@ -572,6 +572,9 @@ void Score::putNote(const QPointF& pos, bool replace)
                   return;
             // voice         = ds->voice(pitch);
             headGroup     = ds->noteHead(pitch);
+            if(headGroup < 0){
+                  return;
+                  }
             stemDirection = ds->stemDirection(pitch);
             }
 
@@ -1095,7 +1098,7 @@ void Score::cmdRemoveTime(int tick, int len)
                   }
             else if (e->isSLine()) {
                   SLine* s = static_cast<SLine*>(e);
-                  if (s->tick() >= tick && s->tick2() < etick)
+                  if ((s->tick() >= tick && s->tick() < etick) || (s->tick2() >= tick && s->tick2() < etick))
                         undoRemoveElement(e);
                   }
             }
@@ -1281,6 +1284,7 @@ void Score::cmdDeleteSelection()
             QList<Element*> el(selection().elements());
             foreach(Element* e, el) {
                   deleteItem(e);
+                  deselect(e);
                   }
             }
       layoutAll = true;
@@ -1416,11 +1420,17 @@ void ScoreView::cmdTuplet(int n)
                   cmdTuplet(n, _score->inputState().cr());
             }
       else {
+            QSet<ChordRest*> set;
             foreach(Element* e, _score->selection().elements()) {
                   if (e->type() == NOTE)
                         e = static_cast<Note*>(e)->chord();
-                  if (e->isChordRest())
-                        cmdTuplet(n, static_cast<ChordRest*>(e));
+                  if (e->isChordRest()) {
+                        ChordRest* cr = static_cast<ChordRest*>(e);
+                        if(!set.contains(cr)) {
+                              cmdTuplet(n, cr);
+                              set.insert(cr);
+                              }
+                        }
                   }
             }
       _score->endCmd();
@@ -1462,7 +1472,6 @@ void ScoreView::cmdTuplet(int n, ChordRest* cr)
       tuplet->setFraction(f);
       Duration baseLen(fr);
       tuplet->setBaseLen(baseLen);
-
       tuplet->setTrack(cr->track());
       tuplet->setTick(tick);
       Measure* measure = cr->measure();
@@ -1518,10 +1527,12 @@ printf("createTuplet at %d <%s> duration <%s> ratio <%s> baseLen <%s>\n",
       ChordRest* cr;
       if (ocr->type() == CHORD) {
             cr = new Chord(this);
-            Note* note = new Note(this);
-            note->setPitch(static_cast<Chord*>(ocr)->upNote()->pitch(), static_cast<Chord*>(ocr)->upNote()->tpc());
-            note->setTrack(track);
-            cr->add(note);
+            foreach(Note* oldNote, static_cast<Chord*>(ocr)->notes()) {
+                  Note* note = new Note(this);
+                  note->setPitch(oldNote->pitch(), oldNote->tpc());
+                  note->setTrack(track);
+                  cr->add(note);
+                  }
             }
       else
             cr = new Rest(this);
