@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: element.cpp 2861 2010-03-09 08:45:08Z lasconic $
+//  $Id: element.cpp 3274 2010-07-12 08:58:45Z wschweer $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -166,6 +166,14 @@ double Element::spatium() const
       return s ? v * s->mag() : v;
       }
 
+//---------------------------------------------------------
+//   magS
+//---------------------------------------------------------
+double Element::magS() const
+      {
+      return _mag * (_score->spatium() /(DPI * SPATIUM20));
+      }
+
 //---------------------------------------------------------
 //   name
 //---------------------------------------------------------
@@ -749,9 +757,11 @@ void StaffLines::draw(QPainter& p) const
 
 double StaffLines::y1() const
       {
+      System* system = measure()->system();
+      if (system == 0)
+            return 0.0;
       double _spatium = spatium();
-
-      double y = measure()->system()->staff(staffIdx())->y();
+      double y = system->staff(staffIdx())->y();
       switch(lines()) {
             case 1:
                   return y + _pos.y() + 1 * _spatium;
@@ -769,9 +779,12 @@ double StaffLines::y1() const
 
 double StaffLines::y2() const
       {
-      double _spatium = spatium();
+      System* system = measure()->system();
+      if (system == 0)
+            return 0.0;
 
-      double y = measure()->system()->staff(staffIdx())->y();
+      double _spatium = spatium();
+      double y = system->staff(staffIdx())->y();
       switch(lines()) {
             case 1:
                   return y + _pos.y() + 3 * _spatium;
