@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: element.h 2926 2010-03-31 19:40:45Z wschweer $
+//  $Id: element.h 3500 2010-09-23 15:23:36Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -189,8 +189,8 @@ class Element {
       void setPos(const QPointF& p)           { _pos = p;                }
       void setPos(double x, double y)         { _pos.rx() = x; _pos.ry() = y;    }
       void movePos(const QPointF& p)          { _pos += p;               }
-      double& rxpos()                         { return _pos.rx();        }
-      double& rypos()                         { return _pos.ry();        }
+      qreal& rxpos()                          { return _pos.rx();        }
+      qreal& rypos()                          { return _pos.ry();        }
       virtual void move(double xd, double yd) { _pos += QPointF(xd, yd); }
       virtual void move(const QPointF& s)     { _pos += s;               }
 
@@ -335,7 +335,7 @@ class Element {
       virtual void toDefault() {  setUserOff(QPointF()); }
 
       double mag() const                        { return _mag;   }
-      double magS() const                       { return _mag * (spatium() /(DPI * SPATIUM20));   }
+      double magS() const;
       virtual void setMag(double val)           { _mag = val;    }
 
 /**
