@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: file.cpp 3096 2010-05-23 19:47:51Z wschweer $
+//  $Id: file.cpp 3269 2010-07-09 20:20:39Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -194,10 +194,14 @@ void MuseScore::loadFile()
       if (fn.isEmpty())
             return;
       Score* score = new Score(defaultStyle);
-      score->read(fn);
-      setCurrentScoreView(appendScore(score));
-      lastOpenPath = score->fileInfo()->path();
-      writeSessionFile(false);
+      if(score->read(fn)) {
+            setCurrentScoreView(appendScore(score));
+            lastOpenPath = score->fileInfo()->path();
+            writeSessionFile(false);
+            }
+      else {
+            delete score;
+            }
       }
 
 //---------------------------------------------------------
@@ -688,9 +692,9 @@ void MuseScore::newFile()
                               KeySigEvent nKey = ks;
                               if (part->transpose().chromatic && !newWizard->useTemplate()) {
                                     int diff = -part->transpose().chromatic;
-                                    nKey.accidentalType = transposeKey(nKey.accidentalType, diff);
+                                    nKey.setAccidentalType(transposeKey(nKey.accidentalType(), diff));
                                     }
-                              if (nKey.accidentalType) {
+                              if (nKey.accidentalType()) {
                                     (*(staff->keymap()))[0] = nKey;
                                     KeySig* keysig = new KeySig(score);
                                     keysig->setTrack(staffIdx * VOICES);
@@ -1194,6 +1198,15 @@ bool Score::read(QDomElement e)
             QString version = e.attribute(QString("version"));
             QStringList sl = version.split('.');
             _mscVersion = sl[0].toInt() * 100 + sl[1].toInt();
+            if (_mscVersion > MSCVERSION) {
+                  // incompatible version
+                  QMessageBox::critical(0, tr("MuseScore"),
+                     QT_TRANSLATE_NOOP("score", "Cannot read this score:\n"
+                        "your version of MuseScore is too old.")
+                     );
+                  return false;
+                  }
+
             for (QDomElement ee = e.firstChildElement(); !ee.isNull(); ee = ee.nextSiblingElement()) {
                   curTrack = -1;
                   QString tag(ee.tagName());
