@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: layout.cpp 3103 2010-05-26 16:14:52Z wschweer $
+//  $Id: layout.cpp 3276 2010-07-12 09:29:28Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -395,7 +395,7 @@ void Score::layoutStage1()
                   KeySigEvent key = staff(staffIdx)->keymap()->key(m->tick());
 
                   char tversatz[75];      // list of already set accidentals for this measure
-                  initLineList(tversatz, key.accidentalType);
+                  initLineList(tversatz, key.accidentalType());
 
                   m->setBreakMMRest(false);
                   if (styleB(ST_createMultiMeasureRests)) {
@@ -439,7 +439,7 @@ void Score::layoutStage1()
                               m->layoutChords0(segment, staffIdx * VOICES, tversatz);
                         if (e && e->type() == KEYSIG) {
                               KeySigEvent oval = staff(staffIdx)->keymap()->key(e->tick() - 1);
-                              static_cast<KeySig*>(e)->setOldSig(oval.accidentalType);
+                              static_cast<KeySig*>(e)->setOldSig(oval.accidentalType());
                               }
                         }
                   }
@@ -1312,7 +1312,7 @@ QList<System*> Score::layoutSystemRow(qreal x, qreal y, qreal rowWidth,
                                     int track = staffIdx * VOICES;
                                     if (!s->element(track)) {
                                           KeySig* ks = new KeySig(this);
-                                          ks->setSig(key1.accidentalType, key2.accidentalType);
+                                          ks->setSig(key1.accidentalType(), key2.accidentalType());
                                           ks->setTrack(track);
                                           ks->setGenerated(true);
                                           ks->setMag(staff->mag());
@@ -1353,9 +1353,6 @@ QList<System*> Score::layoutSystemRow(qreal x, qreal y, qreal rowWidth,
                   if (mb->type() != MEASURE) {
                         if (mb == lmb)
                               break;
-                        mb = mb->next();
-                        if (!mb)
-                              break;
                         continue;
                         }
                   Measure* m = static_cast<Measure*>(mb);
