@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: note.cpp 2969 2010-04-15 11:17:10Z wschweer $
+//  $Id: note.cpp 3269 2010-07-09 20:20:39Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -236,7 +236,7 @@ void Note::setPitch(int a, int b)
 void Note::setTpcFromPitch()
       {
       KeySigEvent key = (staff() && chord()) ? staff()->key(chord()->tick()) : KeySigEvent();
-      _tpc    = pitch2tpc(_pitch, key.accidentalType);
+      _tpc    = pitch2tpc(_pitch, key.accidentalType());
       }
 
 //---------------------------------------------------------
@@ -260,6 +260,9 @@ void Note::setTpc(int v)
 Note::~Note()
       {
       delete _accidental;
+      delete _tieFor;
+      foreach(Element* e, _el)
+            delete e;
       }
 
 //---------------------------------------------------------
@@ -753,7 +756,7 @@ void Note::endDrag()
       Staff* staff = score()->staff(staffIdx);
       int tick     = chord()->tick();
       int clef     = staff->clef(tick);
-      int key      = staff->key(tick).accidentalType;
+      int key      = staff->key(tick).accidentalType();
       int npitch   = line2pitch(_line, clef, key);
       score()->undoChangePitch(this, npitch, pitch2tpc(npitch, key), 0);
       score()->select(this, SELECT_SINGLE, 0);
