@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: page.cpp 2969 2010-04-15 11:17:10Z wschweer $
+//  $Id: page.cpp 3233 2010-06-28 12:54:32Z wschweer $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -48,6 +48,11 @@ Page::Page(Score* s)
    _no(0), _pageNo(0), _copyright(0)
       {
       }
+Page::~Page()
+      {
+      delete _pageNo;
+      delete _copyright;
+      }
 
 //---------------------------------------------------------
 //   tm
