@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: preferences.cpp 3088 2010-05-19 11:51:30Z wschweer $
+//  $Id: preferences.cpp 3276 2010-07-12 09:29:28Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -218,6 +218,7 @@ void Preferences::init()
       defaultPlayDuration     = 300;      // ms
       warnPitchRange          = true;
       followSong              = true;
+      importCharset           = "GBK";
 
       //update
       checkUpdateStartup      = 0;
@@ -429,7 +430,7 @@ void Preferences::read()
 
       defaultPlayDuration    = s.value("defaultPlayDuration", 300).toInt();
       importStyleFile        = s.value("importStyleFile", "").toString();
-      importCharset          = s.value("importCharset", "GBK").toByteArray();
+      importCharset          = s.value("importCharset", "GBK").toString();
       warnPitchRange         = s.value("warnPitchRange", true).toBool();
       followSong             = s.value("followSong", true).toBool();
 
@@ -1141,7 +1142,7 @@ void PreferenceDialog::apply()
       else
             preferences.importStyleFile.clear();
 
-      preferences.importCharset = importCharsetList->currentText().toUtf8();
+      preferences.importCharset = importCharsetList->currentText();
 
       preferences.warnPitchRange = warnPitchRange->isChecked();
 
