@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: score.cpp 3117 2010-06-02 09:21:44Z wschweer $
+//  $Id: score.cpp 3483 2010-09-21 09:05:37Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -291,12 +291,35 @@ Score::Score(const Style& s)
 
 Score::~Score()
       {
+      for (MeasureBase* m = _measures.first(); m;) {
+            MeasureBase* nm = m->next();
+            delete m;
+            m = nm;
+            }
+      foreach(Element* e, _gel)
+            delete e;
+      /*foreach(Beam* b, _beams)
+            delete b;*/
+      foreach(Part* p, _parts)
+            delete p;
+      foreach(Staff* staff, _staves)
+            delete staff;
+      foreach(Page* page, _pages)
+            delete page;
+      foreach(System* s, _systems)
+            delete s;
+      foreach(Excerpt* e, _excerpts)
+            delete e;
+
       delete _pageFormat;
       delete rights;
       delete _undo;           // this also removes _undoStack from Mscore::_undoGroup
       delete _tempomap;
       delete _sigmap;
       delete _repeatList;
+
+      foreach(TextStyle* ts, _textStyles)
+            delete ts;
       }
 
 //---------------------------------------------------------
@@ -330,12 +353,13 @@ bool Score::read(QString name)
       info.setFile(name);
 
       QString cs = info.suffix();
-
-      if (cs == "mscz") {
+      QString csl = cs.toLower();
+      
+      if (csl == "mscz") {
             if (!loadCompressedMsc(name))
                   return false;
             }
-      else if (cs.toLower() == "msc" || cs.toLower() == "mscx") {
+      else if (csl == "msc" || csl == "mscx") {
             if (!loadMsc(name))
                   return false;
             }
@@ -348,39 +372,40 @@ bool Score::read(QString name)
                         loadStyle(&f);
                   }
 
-            if (cs == "xml") {
+            if (csl == "xml") {
                   importMusicXml(name);
                   connectSlurs();
                   }
-            else if (cs == "mxl")
+            else if (csl == "mxl")
                   importCompressedMusicXml(name);
-            else if (cs.toLower() == "mid" || cs.toLower() == "midi" || cs.toLower() == "kar") {
+            else if (csl == "mid" || csl == "midi" || csl == "kar") {
                   if (!importMidi(name))
                         return false;
                   }
-            else if (cs == "md") {
+            else if (csl == "md") {
                   if (!importMuseData(name))
                         return false;
                   }
-            else if (cs == "ly") {
+            else if (csl == "ly") {
                   if (!importLilypond(name))
                         return false;
                   }
-            else if (cs.toLower() == "mgu" || cs.toLower() == "sgu") {
+            else if (csl == "mgu" || csl == "sgu") {
                   if (!importBB(name))
                         return false;
                   }
-            else if (cs.toLower() == "cap") {
+            else if (csl == "cap") {
                   if (!importCapella(name))
                         return false;
                   connectSlurs();
                   }
-            else if (cs.toLower() == "ove") {
-            	if(!importOve(name))
-            		return false;
-				}
+            else if (csl == "ove") {
+                  if(!importOve(name))
+            		        return false;
+				          }
             else {
                   printf("unknown file suffix <%s>, name <%s>\n", qPrintable(cs), qPrintable(name));
+                  return false;
                   }
             }
 
@@ -1108,11 +1133,12 @@ void Score::setClean(bool val)
       if (_dirty != val) {
             _dirty         = val;
             _playlistDirty = true;
-            _autosaveDirty = true;
             emit dirtyChanged(this);
             }
-      if (_dirty)
+      if (_dirty) {
+            _autosaveDirty = true;
             _playlistDirty = true;
+            }
       }
 
 //---------------------------------------------------------
@@ -2104,8 +2130,8 @@ KeySig* Score::keySigFactory(KeySigEvent e)
       KeySig* ks;
       if (!e.isValid())
             return 0;
-      if (e.custom) {
-            ks = new KeySig(*customKeysigs[e.customType]);
+      if (e.custom()) {
+            ks = new KeySig(*customKeysigs[e.customType()]);
             }
       else {
             ks = new KeySig(this);
