@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: score.h 3113 2010-05-29 09:39:14Z wschweer $
+//  $Id: score.h 3492 2010-09-22 09:08:45Z lasconic $
 //
 //  Copyright (C) 2002-2010 Werner Schweer and others
 //
@@ -314,7 +314,7 @@ class Score : public QObject {
       void addTempo();
       void addMetronome();
 
-      void undoSigInsertTime(int, int);
+     
 
       void cmdAddChordName2();
       int processPendingNotes(QList<MNote*>* notes, int, int);
@@ -427,6 +427,7 @@ class Score : public QObject {
       void undoChangeMeasureLen(Measure* m, int oldTicks, int newTicks);
       void undoChangeElement(Element* oldElement, Element* newElement);
       void undoInsertTime(int tick, int len);
+      void undoSigInsertTime(int, int);
       void undoChangeRepeatFlags(Measure*, int);
       void undoChangeVoltaEnding(Volta* volta, const QList<int>& l);
       void undoChangeVoltaText(Volta* volta, const QString& s);
@@ -466,7 +467,7 @@ class Score : public QObject {
       void changeCRlen(ChordRest* cr, const Duration&);
 
       Fraction makeGap(ChordRest*, const Fraction&, Tuplet*);
-      void makeGap1(int tick, int staffIdx, Fraction len);
+      bool makeGap1(int tick, int staffIdx, Fraction len);
 
       Rest* addRest(int tick, int track, Duration, Tuplet*);
       Rest* addRest(Segment* seg, int track, Duration d, Tuplet*);
