@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: scscore.cpp 3026 2010-05-02 21:19:59Z wschweer $
+//  $Id: scscore.cpp 3425 2010-08-28 14:58:38Z lasconic $
 //
 //  Copyright (C) 2009-2010 Werner Schweer and others
 //
@@ -141,7 +141,7 @@ static QScriptValue prototype_Score_call(QScriptContext* context, QScriptEngine*
                   {
                   Text* t = score->getText(TEXT_TITLE);
                   if (argc == 0) {
-                        QString s = t ? t->getText() : "";
+                        QString s = t ? t->getText().replace(QString(0xe10d), QString(0x266D)) : "";
                         return qScriptValueFromValue(context->engine(), s);
                         }
                   else if (argc == 1) {
@@ -158,7 +158,7 @@ static QScriptValue prototype_Score_call(QScriptContext* context, QScriptEngine*
                   {
                   Text* t = score->getText(TEXT_SUBTITLE);
                   if (argc == 0) {
-                        QString s = t ? t->getText() : "";
+                        QString s = t ? t->getText().replace(QString(0xe10d), QString(0x266D)) : "";
                         return qScriptValueFromValue(context->engine(), s);
                         }
                   else if (argc == 1) {
@@ -175,7 +175,7 @@ static QScriptValue prototype_Score_call(QScriptContext* context, QScriptEngine*
                   {
                   Text* t = score->getText(TEXT_COMPOSER);
                   if (argc == 0) {
-                        QString s = t ? t->getText() : "";
+                        QString s = t ? t->getText().replace(QString(0xe10d), QString(0x266D)) : "";
                         return qScriptValueFromValue(context->engine(), s);
                         }
                   else if (argc == 1) {
@@ -192,7 +192,7 @@ static QScriptValue prototype_Score_call(QScriptContext* context, QScriptEngine*
                   {
                   Text* t = score->getText(TEXT_POET);
                   if (argc == 0) {
-                        QString s = t ? t->getText() : "";
+                        QString s = t ? t->getText().replace(QString(0xe10d), QString(0x266D)) : "";
                         return qScriptValueFromValue(context->engine(), s);
                         }
                   else if (argc == 1) {
@@ -239,7 +239,7 @@ static QScriptValue prototype_Score_call(QScriptContext* context, QScriptEngine*
                   break;
             case 6:    // "setExpandRepeat",
                   if (argc == 1) {
-                        bool f = context->argument(1).toBool();
+                        bool f = context->argument(0).toBool();
                         getAction("repeat")->setChecked(f);
                         preferences.midiExpandRepeats = f;
                         score->updateRepeatList(f);
@@ -382,14 +382,14 @@ static QScriptValue prototype_Score_call(QScriptContext* context, QScriptEngine*
                             Staff* st = score->staff(0);
                             KeyList* kl = st->keymap();
                             KeySigEvent key = kl->key(0);
-                            if(key.custom){
+                            if(key.custom()){
                                  QString s = "undefined";
                                  return qScriptValueFromValue(context->engine(), s);
                                  }
-                            result = key.accidentalType;
+                            result = key.accidentalType();
                             int tr =  st->part()->transpose().chromatic;
-                            if (tr){
-                                result = transposeKey(key.accidentalType, tr);
+                            if (!score->styleB(ST_concertPitch) && tr){
+                                result = transposeKey(key.accidentalType(), tr);
                                 }
                             }
                         return qScriptValueFromValue(context->engine(), result);
