@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: seq.cpp 2981 2010-04-18 14:40:17Z lasconic $
+//  $Id: seq.cpp 3343 2010-08-05 08:31:59Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -115,8 +115,9 @@ void Seq::setScoreView(ScoreView* v)
       {
       if (cv !=v && cs) {
             disconnect(cs, SIGNAL(selectionChanged(int)), this, SLOT(selectionChanged(int)));
-            cs = v ? v->score() : 0;
+            markedNotes.clear();
             stop();
+            cs = v ? v->score() : 0;
 #ifndef __MINGW32__
             while (state != STOP)
                   usleep(100000);
@@ -368,11 +369,14 @@ void MuseScore::seqStopped()
 
 void Seq::guiStop()
       {
-      if (!cs)
-            return;
       QAction* a = getAction("play");
       a->setChecked(false);
 
+      if (!cs) {
+            markedNotes.clear();
+            return;
+            }
+
       //
       // deselect all selected notes
       //
@@ -1022,7 +1026,7 @@ void Seq::prevChord()
                   break;
             --i;
             }
-      //go the previous chord      
+      //go the previous chord
       if (i != events.constBegin()) {
             i = playPos;
             for (;;) {
