@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: sym.cpp 2706 2010-02-13 09:29:58Z lasconic $
+//  $Id: sym.cpp 3355 2010-08-06 14:24:20Z wschweer $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -40,8 +40,8 @@ SymbolNames lilypondNames[] = {
       { outsidewholerestSym,  QT_TRANSLATE_NOOP("symbol", "outside whole rest"),   "rests.0o" },
       { outsidehalfrestSym,   QT_TRANSLATE_NOOP("symbol", "outside half rest"),    "rests.1o" },
       { rest_M3,              QT_TRANSLATE_NOOP("symbol", "rest M3"),              "rests.M3" },
-      { breverestSym,         QT_TRANSLATE_NOOP("symbol", "breve rest"),           "rests.M2" },
-      { longarestSym,         QT_TRANSLATE_NOOP("symbol", "longa rest"),           "rests.M1" },
+      { breverestSym,         QT_TRANSLATE_NOOP("symbol", "breve rest"),           "rests.M1" },
+      { longarestSym,         QT_TRANSLATE_NOOP("symbol", "longa rest"),           "rests.M2" },
       { rest4Sym,             QT_TRANSLATE_NOOP("symbol", "quart rest"),           "rests.2" },
       { clasquartrestSym,     QT_TRANSLATE_NOOP("symbol", "clas quart rest"),      "rests.2classical" },
       { rest8Sym,             QT_TRANSLATE_NOOP("symbol", "eight rest"),           "rests.3" },
@@ -316,7 +316,7 @@ SymCode pSymbols[] = {
       SymCode(0x011c, -1),
       SymCode(0x0124, -1),
       SymCode(0x0134, -1),
-      SymCode(0x015c, -1),            
+      SymCode(0x015c, -1),
       SymCode(0x016c, -1),
 
       SymCode(0x00e0, -1),
@@ -357,10 +357,10 @@ SymCode pSymbols[] = {
       SymCode(0x011d, -1),
       SymCode(0x0125, -1),
       SymCode(0x0135, -1),
-      SymCode(0x015d, -1),            
+      SymCode(0x015d, -1),
       SymCode(0x016d, -1),
-      
-      
+
+
       SymCode(0x00BC, -1, "1/4", SYMBOL_FRACTION),
       SymCode(0x00BD, -1, "1/2", SYMBOL_FRACTION),
       SymCode(0x00BE, -1, "3/4", SYMBOL_FRACTION),
@@ -514,6 +514,8 @@ void Sym::draw(QPainter& painter, double mag, qreal x, qreal y, int n) const
 
 QString symToHtml(const Sym& s, int leftMargin)
       {
+      leftMargin = int((leftMargin * PDPI) / DPI);
+
       double size    = s.font().pixelSize() * 72.0 / DPI;
       QString family = s.font().family();
       return QString(
@@ -537,6 +539,8 @@ QString symToHtml(const Sym& s, int leftMargin)
 
 QString symToHtml(const Sym& s1, const Sym& s2, int leftMargin)
       {
+      leftMargin = (leftMargin * PDPI) / DPI;
+
       QFont f        = s1.font();
       double size    = s1.font().pixelSize() * 72.0 / DPI;
       QString family = f.family();
