@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: text.cpp 3077 2010-05-14 11:48:04Z wschweer $
+//  $Id: text.cpp 3355 2010-08-06 14:24:20Z wschweer $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -46,8 +46,10 @@ TextBase::TextBase()
       {
       _refCount     = 1;
       _doc          = new QTextDocument(0);
+      _doc->setDocumentMargin(1.0);
       _doc->setUseDesignMetrics(true);
       _doc->setUndoRedoEnabled(true);
+      _doc->documentLayout()->setProperty("cursorWidth", QVariant(2));
 
       _hasFrame     = false;
       _frameWidth   = 0.35;         // default line width
@@ -63,6 +65,11 @@ TextBase::TextBase()
       _doc->setDefaultTextOption(to);
       }
 
+TextBase::~TextBase()
+      {
+      delete _doc;
+      }
+
 //---------------------------------------------------------
 //   TextBase
 //---------------------------------------------------------
@@ -80,8 +87,8 @@ TextBase::TextBase(const TextBase& t)
       _layoutWidth  = t._layoutWidth;
       frame         = t.frame;
       _bbox         = t._bbox;
-      _doc->documentLayout()->setPaintDevice(pdev);
-      layout(_layoutWidth);
+//      _doc->documentLayout()->setPaintDevice(pdev);
+//      layout(_layoutWidth);
       }
 
 //---------------------------------------------------------
@@ -191,6 +198,7 @@ void TextBase::setText(const QString& s, Align align)
       tf.setFont(_doc->defaultFont());
       cursor.setBlockCharFormat(tf);
       cursor.insertText(s);
+      _doc->setTextWidth(_doc->idealWidth());  // to make alignment work
       }
 
 //---------------------------------------------------------
@@ -295,20 +303,12 @@ bool TextBase::readProperties(QDomElement e)
 
 void TextBase::layout(double w)
       {
-      _layoutWidth = w;
-      if (!_doc->isModified())
-            return;
-
-      _doc->documentLayout()->setPaintDevice(pdev);
+      const double mag = DPI / PDPI;
+      w /= mag;
 
       if (w <= 0.0)
             w = _doc->idealWidth();
-      else {
-            QTextOption to = _doc->defaultTextOption();
-            to.setUseDesignMetrics(true);
-            to.setWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
-            _doc->setDefaultTextOption(to);
-            }
+
       _doc->setTextWidth(w);   // to make alignment work
 
       if (_hasFrame) {
@@ -330,6 +330,7 @@ void TextBase::layout(double w)
                         frame.setWidth(frame.height());
                         }
                   }
+            frame = QRectF(frame.x() * mag, frame.y() * mag, frame.width() * mag, frame.height() * mag);
             double w = (_paddingWidth + _frameWidth * .5) * DPMM;
             frame.adjust(-w, -w, w, w);
             w = _frameWidth * DPMM;
@@ -337,8 +338,7 @@ void TextBase::layout(double w)
             }
       else {
             _bbox = _doc->documentLayout()->frameBoundingRect(_doc->rootFrame());
-//            double m = DPI / PDPI;
-//            _bbox.adjust(_bbox.x() * m, _bbox.y() * m, _bbox.width() * m, _bbox.height() * m);
+            _bbox = QRectF(_bbox.x() * mag, _bbox.y() * mag, _bbox.width() * mag, _bbox.height() * mag);
             }
       _doc->setModified(false);
       }
@@ -364,9 +364,10 @@ void TextBase::draw(QPainter& p, QTextCursor* cursor) const
       QColor color = p.pen().color();
       c.palette.setColor(QPalette::Text, color);
 
-      _doc->documentLayout()->setProperty("cursorWidth", QVariant(int(lrint(2.0*DPI/PDPI))));
-// p.scale(DPI/PDPI, DPI/PDPI);
+      p.save();
+      p.scale(DPI/PDPI, DPI/PDPI);
       _doc->documentLayout()->draw(&p, c);
+      p.restore();
 
       // draw frame
       if (_hasFrame) {
@@ -778,17 +779,21 @@ void TextB::writeProperties(Xml& xml, bool writeText) const
 
       TextStyle* st = score()->textStyle(_textStyle);
       if (st == 0 || _align != st->align) {
-            if (_align & (ALIGN_RIGHT | ALIGN_HCENTER)) {          // default is ALIGN_LEFT
-                  xml.tag("halign", (_align & ALIGN_RIGHT) ? "right" : "center");
-                  }
-            if (_align & (ALIGN_BOTTOM | ALIGN_VCENTER | ALIGN_BASELINE)) {        // default is ALIGN_TOP
-                  if (_align & ALIGN_BOTTOM)
-                        xml.tag("valign", "bottom");
-                  else if (_align & ALIGN_VCENTER)
-                        xml.tag("valign", "center");
-                  else if (_align & ALIGN_BASELINE)
-                        xml.tag("valign", "baseline");
-                  }
+            if (_align & ALIGN_HCENTER)
+                  xml.tag("halign", "center");
+            else if (_align & ALIGN_RIGHT)
+                  xml.tag("halign", "right");
+            else
+                  xml.tag("halign", "left");
+
+            if (_align & ALIGN_BOTTOM)
+                  xml.tag("valign", "bottom");
+            else if (_align & ALIGN_VCENTER)
+                  xml.tag("valign", "center");
+            else if (_align & ALIGN_BASELINE)
+                  xml.tag("valign", "baseline");
+            else
+                  xml.tag("valign", "top");
             }
       if (st == 0 || _xoff != st->xoff)
             xml.tag("xoffset", _xoff);
@@ -802,7 +807,7 @@ void TextB::writeProperties(Xml& xml, bool writeText) const
       if (st == 0 || _offsetType != st->offsetType) {
             const char* p = 0;
             switch(_offsetType) {
-                  case OFFSET_SPATIUM:                    break;
+                  case OFFSET_SPATIUM:    p = "spatium"; break;
                   case OFFSET_ABS:        p = "absolute"; break;
                   }
             if (p)
@@ -847,20 +852,26 @@ bool TextB::readProperties(QDomElement e)
       else if (tag == "align")            // obsolete
             _align = Align(val.toInt());
       else if (tag == "halign") {
+            _align &= ~(ALIGN_HCENTER | ALIGN_RIGHT);
             if (val == "center")
-                  _align |= ALIGN_HCENTER;
+                _align |= ALIGN_HCENTER;
             else if (val == "right")
-                  _align |= ALIGN_RIGHT;
+                _align |= ALIGN_RIGHT;
+            else if (val == "left")
+                  ;
             else
                   printf("Text::readProperties: unknown alignment: <%s>\n", qPrintable(val));
             }
       else if (tag == "valign") {
+            _align &= ~(ALIGN_VCENTER | ALIGN_BOTTOM | ALIGN_BASELINE);
             if (val == "center")
                   _align |= ALIGN_VCENTER;
             else if (val == "bottom")
                   _align |= ALIGN_BOTTOM;
             else if (val == "baseline")
                   _align |= ALIGN_BASELINE;
+            else if (val == "top")
+                  ;
             else
                   printf("Text::readProperties: unknown alignment: <%s>\n", qPrintable(val));
             }
@@ -924,7 +935,7 @@ void TextB::startEdit(ScoreView* view, const QPointF& p)
 
 bool TextB::isEditable()
       {
-      return !((type() == TEXT) && (subtype() == TEXT_MEASURE_NUMBER));
+      return !((type() == TEXT) && ((subtype() == TEXT_MEASURE_NUMBER) || (subtype() == TEXT_PAGE_NUMBER_ODD) || (subtype() == TEXT_PAGE_NUMBER_EVEN)));
       }
 
 //---------------------------------------------------------
@@ -1167,11 +1178,15 @@ QPainterPath TextB::shape() const
       {
       QPainterPath pp;
 
+      const double mag = DPI / PDPI;
       for (QTextBlock tb = doc()->begin(); tb.isValid(); tb = tb.next()) {
             QTextLayout* tl = tb.layout();
             int n = tl->lineCount();
-            for (int i = 0; i < n; ++i)
-                  pp.addRect(tl->lineAt(0).naturalTextRect().translated(tl->position()));
+            for (int i = 0; i < n; ++i) {
+                  QRectF r(tl->lineAt(0).naturalTextRect().translated(tl->position()));
+                  r = QRectF(r.x() * mag, r.y() * mag, r.width() * mag, r.height() * mag);
+                  pp.addRect(r);
+                  }
             }
       return pp;
       }
@@ -1183,10 +1198,11 @@ QPainterPath TextB::shape() const
 
 qreal TextB::baseLine() const
       {
+      const double mag = DPI / PDPI;
       for (QTextBlock tb = doc()->begin(); tb.isValid(); tb = tb.next()) {
             const QTextLayout* tl = tb.layout();
             if (tl->lineCount())
-                  return tl->lineAt(0).ascent() + tl->position().y();
+                  return (tl->lineAt(0).ascent() + tl->position().y()) * mag;;
             }
       return 0.0;
       }
@@ -1267,6 +1283,10 @@ bool TextB::setCursor(const QPointF& p, QTextCursor::MoveMode mode)
       QPointF pt  = p - canvasPos();
       if (!bbox().contains(pt))
             return false;
+
+      const double mag = DPI / PDPI;
+      pt /= mag;
+
       int idx = doc()->documentLayout()->hitTest(pt, Qt::FuzzyHit);
       if (idx == -1)
             return true;
