@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: tuplet.cpp 3096 2010-05-23 19:47:51Z wschweer $
+//  $Id: tuplet.cpp 3499 2010-09-22 20:53:45Z wschweer $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -259,11 +259,13 @@ void Tuplet::layout()
       p2 -= mp;
 
       if (_userModified) {
-            p1.rx() += _p1.x();
-            p2.rx() += _p2.x();
+//            p1.rx() += _p1.x();
+//            p2.rx() += _p2.x();
+            p1 += _p1;
+            p2 += _p2;
             }
-      _p1.ry() = p1.y();
-      _p2.ry() = p2.y();
+//      _p1.ry() = p1.y();
+//      _p2.ry() = p2.y();
 
       // center number
       qreal x3 = 0.0, y3 = 0.0;
