@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: undo.cpp 3117 2010-06-02 09:21:44Z wschweer $
+//  $Id: undo.cpp 3483 2010-09-21 09:05:37Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -821,10 +821,16 @@ void ChangeNoteHead::flip()
       QRectF r = note->abbox();
       note->setHeadGroup(group);
       note->setHeadType(type);
-      r |= note->abbox();
-      group = headGroup;
-      type  = t;
-      note->score()->addRefresh(r);
+      if(note->noteHead() != -1){
+        r |= note->abbox();
+        group = headGroup;
+        type  = t;
+        note->score()->addRefresh(r);
+        }
+      else{
+          note->setHeadGroup(headGroup);
+          note->setHeadType(t);
+          }
 //      note->score()->end();
       }
 
