@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: utils.cpp 3119 2010-06-02 09:58:58Z wschweer $
+//  $Id: utils.cpp 3503 2010-09-24 12:09:37Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -409,10 +409,18 @@ static const char* valu[] = {
             "C","C#","D","D#","E","F","F#","G","G#","A","A#","H"
             };
 
-//---------------------------------------------------------
-//   pitch2string
-//---------------------------------------------------------
-
+/*!
+ * Returns the string representation of the given pitch.
+ *
+ * Returns the latin letter name, accidental, and octave numeral.
+ * Uses upper case only for pitches 0-24.
+ *
+ * @param v
+ *  The pitch number of the note.
+ *
+ * @return
+ *  The string representation of the note.
+ */
 QString pitch2string(int v)
       {
       if (v < 0 || v > 127)
@@ -423,11 +431,13 @@ QString pitch2string(int v)
       return QString("%1%2").arg(octave < 0 ? valu[i] : vall[i]).arg(octave);
       }
 
-//---------------------------------------------------------
-//   Interval
-//    steps - semitones
-//---------------------------------------------------------
-
+/*!
+ * An array of all supported interval sorted by size.
+ *
+ * Because intervals can be spelled differently, this array
+ * tracks all the different valid intervals. They are arranged
+ * in diatonic then chromatic order.
+ */
 Interval intervalList[26] = {
       Interval(0, 0),         //  0 Perfect Unison
       Interval(0, 1),         //  1 Augmented Unison
@@ -464,11 +474,18 @@ Interval intervalList[26] = {
       Interval(7, 12)         // 25 Perfect Octave
       };
 
-//---------------------------------------------------------
-//   chromatic2diatonic
-//    find the most likely interval for an
-//    semitone distance
-//---------------------------------------------------------
+/*!
+ * Finds the most likely diatonic interval for a semitone distance.
+ *
+ * Uses the most common diatonic intervals.
+ *
+ * @param
+ *  The number of semitones in the chromatic interval.
+ *  Negative semitones will simply be made positive.
+ *
+ * @return
+ *  The number of diatonic steps in the interval.
+ */
 
 int chromatic2diatonic(int semitones)
       {
@@ -512,60 +529,53 @@ int searchInterval(int steps, int semitones)
       return -1;
       }
 
-//---------------------------------------------------------
-//   transposeInterval
-//---------------------------------------------------------
+/*!
+ * Transposes both pitch and spelling for a note given an interval.
+ *
+ * Uses addition for pitch and transposeTpc() for spelling.
+ *
+ * @param pitch
+ *  The initial (current) pitch. (pitch)
+ * @param tpc
+ *  The initial spelling. (tpc)
+ * @param rpitch
+ *  A pointer to the transposed pitch, calculated by this function. (pitch)
+ * @param rtpc
+ *  A pointer to the transposed spelling. (tcp)
+ * @param interval
+ *  The interval to transpose by.
+ * @param useDoubleSharpsFlats
+ *  Determines whether the output may include double sharbs or flats (Abb)
+ *  or should use an enharmonic pitch (Abb = G).
+ */
 
 void transposeInterval(int pitch, int tpc, int* rpitch, int* rtpc, Interval interval,
    bool useDoubleSharpsFlats)
       {
       *rpitch   = pitch + interval.chromatic;
-      int steps = interval.diatonic;
-
-      int minAlter;
-      int maxAlter;
-      if (useDoubleSharpsFlats) {
-            minAlter = -2;
-            maxAlter = 2;
-            }
-      else {
-            minAlter = -1;
-            maxAlter = 1;
-            }
-
-      int step, alter;
-      for (;;) {
-            int octave = (pitch / 12);
-
-            step = tpc2step(tpc) + steps;
-            while (step < 0) {
-                  step += 7;
-                  octave -= 1;
-                  }
-            while (step >= 7) {
-                  step -= 7;
-                  octave += 1;
-                  }
-
-            int p1     = tpc2pitch(step2tpc(step, 0)) + octave * 12;
-            alter      = interval.chromatic - (p1 - pitch);
-            if (alter < 0)
-                  alter = -((-alter) % 12);
-            else
-                  alter %= 12;
-            if (alter > maxAlter)
-                  ++steps;
-            else if (alter < minAlter)
-                  --steps;
-            else
-                  break;
-            }
-      *rtpc  = step2tpc(step, alter);
+      *rtpc = transposeTpc(tpc, interval, useDoubleSharpsFlats);
+      
       }
 
-//---------------------------------------------------------
-//   transposeTpc
-//---------------------------------------------------------
+/*!
+ * Transposes a pitch spelling given an interval.
+ * 
+ * This function transposes a pitch spelling using first
+ * a diatonic transposition and then calculating any accidentals.
+ * This insures that the note is changed by the correct number of
+ * scale degrees unless it would require too many accidentals.
+ *
+ * @param tpc
+ *  The initial pitch spelling.
+ * @param interval
+ *  The interval to be transposed by.
+ * @param useDoubleSharpsFlats
+ *  Determines whether the output may include double sharps or flats (Abb)
+ *  or should use an enharmonic pitch (Abb = G).
+ *
+ * @return
+ *  The transposed pitch spelling (tpc).
+ */
 
 int transposeTpc(int tpc, Interval interval, bool useDoubleSharpsFlats)
       {
@@ -585,7 +595,7 @@ int transposeTpc(int tpc, Interval interval, bool useDoubleSharpsFlats)
       int steps     = interval.diatonic;
       int semitones = interval.chromatic;
 
-      if (semitones == 0)
+      if (semitones == 0 && steps == 0)
             return tpc;
 
       int step, alter;
@@ -599,25 +609,34 @@ int transposeTpc(int tpc, Interval interval, bool useDoubleSharpsFlats)
             int p1 = tpc2pitch(step2tpc(step, 0));
             alter  = semitones - (p1 - pitch);
             // alter  = p1 + semitones - pitch;
-            if (alter < 0)
-                  alter = -((-alter) % 12);
-            else
-                  alter %= 12;
-            if (alter > maxAlter)
+	          if (alter < 0) {
+	                alter *= -1;
+	                alter = 12 - alter;
+	                }
+            alter %= 12;
+	          if (alter > 6)
+	               alter -= 12;
+	          if (alter > maxAlter)
                   ++steps;
             else if (alter < minAlter)
                   --steps;
             else
                   break;
+            printf("  again alter %d steps %d, step %d\n", alter, steps, step);
             }
+      printf("  = step %d alter %d  tpc %d\n", step, alter, step2tpc(step, alter));
       return step2tpc(step, alter);
       }
 
 static int _majorVersion, _minorVersion, _updateVersion;
 
-//---------------------------------------------------------
-//   version
-//---------------------------------------------------------
+/*!
+ * Returns the program version
+ *
+ * @return
+ *  Version in the format: MMmmuu
+ *  Where M=Major, m=minor, and u=update
+ */
 
 int version()
       {
